==> babel-plugin-mockable-imports-1.0.0.tgz: package/lib/helpers.js <==
"use strict";

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _wrapNativeSuper(Class) { var _cache = typeof Map === "function" ? new Map() : undefined; _wrapNativeSuper = function _wrapNativeSuper(Class) { if (Class === null || !_isNativeFunction(Class)) return Class; if (typeof Class !== "function") { throw new TypeError("Super expression must either be null or a function"); } if (typeof _cache !== "undefined") { if (_cache.has(Class)) return _cache.get(Class); _cache.set(Class, Wrapper); } function Wrapper() { return _construct(Class, arguments, _getPrototypeOf(this).constructor); } Wrapper.prototype = Object.create(Class.prototype, { constructor: { value: Wrapper, enumerable: false, writable: true, configurable: true } }); return _setPrototypeOf(Wrapper, Class); }; return _wrapNativeSuper(Class); }

function isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _construct(Parent, args, Class) { if (isNativeReflectConstruct()) { _construct = Reflect.construct; } else { _construct = function _construct(Parent, args, Class) { var a = [null]; a.push.apply(a, args); var Constructor = Function.bind.apply(Parent, a); var instance = new Constructor(); if (Class) _setPrototypeOf(instance, Class.prototype); return instance; }; } return _construct.apply(null, arguments); }

function _isNativeFunction(fn) { return Function.toString.call(fn).indexOf("[native code]") !== -1; }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var MockingError =
/*#__PURE__*/
function (_Error) {
  _inheritsLoose(MockingError, _Error);

  function MockingError(msg) {
    return _Error.call(this, msg) || this;
  }

  return MockingError;
}(_wrapNativeSuper(Error));

var ImportMap =
/*#__PURE__*/
function () {
  function ImportMap(imports) {
    /**
     * A mapping of import local name (or alias) to metadata about where
     * the import came from.
     */
    this.$meta = imports;
    this.$restore();
  }
  /**
   * Replace true imports with mocks.
   *
   * If mocks are already active when this is called, the mocks in `imports`
   * are merged with the active mocks.
   *
   * @param {Object} imports -
   *   Map of file path (as used in the module that imports the file) to
   *   replacement content for that module.
   */


  var _proto = ImportMap.prototype;

  _proto.$mock = function $mock(imports) {
    var _this = this;

    Object.keys(imports).forEach(function (source) {
      var sourceImports = imports[source];

      if (typeof sourceImports === 'function') {
        sourceImports = {
          "default": sourceImports
        };
      } // Handle namespace imports (`import * as foo from "foo"`).


      var namespaceAliases = Object.keys(_this.$meta).filter(function (alias) {
        var _this$$meta$alias = _this.$meta[alias],
            source_ = _this$$meta$alias[0],
            symbol_ = _this$$meta$alias[1];
        return source_ === source && symbol_ === '*';
      });
      namespaceAliases.forEach(function (alias) {
        _this[alias] = sourceImports;
      }); // Handle named imports (`import { foo } from "..."`).

      Object.keys(sourceImports).forEach(function (symbol) {
        var aliases = Object.keys(_this.$meta).filter(function (alias) {
          var _this$$meta$alias2 = _this.$meta[alias],
              source_ = _this$$meta$alias2[0],
              symbol_ = _this$$meta$alias2[1];
          return source_ === source && symbol_ === symbol;
        });

        if (aliases.length === 0 && namespaceAliases.length === 0) {
          throw new Error("Module does not import \"" + symbol + "\" from \"" + source + "\"");
        }

        aliases.forEach(function (alias) {
          _this[alias] = sourceImports[symbol];
        });
      });
    });
  }
  /**
   * Replace any active mocks with the original imports.
   *
   * This function does nothing if called when no mocks are active.
   */
  ;

  _proto.$restore = function $restore() {
    var _this2 = this;

    var proto = Object.getPrototypeOf(this);
    Object.keys(this.$meta).forEach(function (alias) {
      if (proto.hasOwnProperty(alias)) {
        // Skip imports which conflict with special methods.
        return;
      }

      var _this2$$meta$alias = _this2.$meta[alias],
          value = _this2$$meta$alias[2];
      _this2[alias] = value;
    });
  };

  return ImportMap;
}();

module.exports = {
  ImportMap: ImportMap,
  MockingError: MockingError
};

==> babel-plugin-mockable-imports-1.1.0.tgz: package/lib/helpers.js <==
"use strict";

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _wrapNativeSuper(Class) { var _cache = typeof Map === "function" ? new Map() : undefined; _wrapNativeSuper = function _wrapNativeSuper(Class) { if (Class === null || !_isNativeFunction(Class)) return Class; if (typeof Class !== "function") { throw new TypeError("Super expression must either be null or a function"); } if (typeof _cache !== "undefined") { if (_cache.has(Class)) return _cache.get(Class); _cache.set(Class, Wrapper); } function Wrapper() { return _construct(Class, arguments, _getPrototypeOf(this).constructor); } Wrapper.prototype = Object.create(Class.prototype, { constructor: { value: Wrapper, enumerable: false, writable: true, configurable: true } }); return _setPrototypeOf(Wrapper, Class); }; return _wrapNativeSuper(Class); }

function isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _construct(Parent, args, Class) { if (isNativeReflectConstruct()) { _construct = Reflect.construct; } else { _construct = function _construct(Parent, args, Class) { var a = [null]; a.push.apply(a, args); var Constructor = Function.bind.apply(Parent, a); var instance = new Constructor(); if (Class) _setPrototypeOf(instance, Class.prototype); return instance; }; } return _construct.apply(null, arguments); }

function _isNativeFunction(fn) { return Function.toString.call(fn).indexOf("[native code]") !== -1; }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var MockingError =
/*#__PURE__*/
function (_Error) {
  _inheritsLoose(MockingError, _Error);

  function MockingError(msg) {
    return _Error.call(this, msg) || this;
  }

  return MockingError;
}(_wrapNativeSuper(Error));

var ImportMap =
/*#__PURE__*/
function () {
  function ImportMap(imports) {
    /**
     * A mapping of import local name (or alias) to metadata about where
     * the import came from.
     */
    this.$meta = imports;
    this.$restore();
  }
  /**
   * Replace true imports with mocks.
   *
   * If mocks are already active when this is called, the mocks in `imports`
   * are merged with the active mocks.
   *
   * @param {Object} imports -
   *   Map of file path (as used in the module that imports the file) to
   *   replacement content for that module.
   */


  var _proto = ImportMap.prototype;

  _proto.$mock = function $mock(imports) {
    var _this = this;

    Object.keys(imports).forEach(function (source) {
      var sourceImports = imports[source];
      var esImports = sourceImports;

      if (typeof esImports === 'function') {
        esImports = {
          "default": esImports
        };
      } // Handle namespace ES imports (`import * as foo from "foo"`).


      var namespaceAliases = Object.keys(_this.$meta).filter(function (alias) {
        var _this$$meta$alias = _this.$meta[alias],
            source_ = _this$$meta$alias[0],
            symbol_ = _this$$meta$alias[1];
        return source_ === source && symbol_ === '*';
      });
      namespaceAliases.forEach(function (alias) {
        _this[alias] = esImports;
      }); // Handle CJS imports (`var foo = require("bar")`).

      var cjsAliases = Object.keys(_this.$meta).filter(function (alias) {
        var _this$$meta$alias2 = _this.$meta[alias],
            source_ = _this$$meta$alias2[0],
            symbol_ = _this$$meta$alias2[1];
        return source_ === source && symbol_ === '<CJS>';
      });
      cjsAliases.forEach(function (alias) {
        _this[alias] = sourceImports;
      }); // Handle named ES imports (`import { foo } from "..."`) or
      // destructured CJS imports (`var { foo } = require("...")`).

      Object.keys(esImports).forEach(function (symbol) {
        var aliases = Object.keys(_this.$meta).filter(function (alias) {
          var _this$$meta$alias3 = _this.$meta[alias],
              source_ = _this$$meta$alias3[0],
              symbol_ = _this$$meta$alias3[1];
          return source_ === source && symbol_ === symbol;
        });

        if (aliases.length === 0 && namespaceAliases.length === 0 && cjsAliases.length === 0) {
          throw new Error("Module does not import \"" + symbol + "\" from \"" + source + "\"");
        }

        aliases.forEach(function (alias) {
          _this[alias] = esImports[symbol];
        });
      });
    });
  }
  /**
   * Replace any active mocks with the original imports.
   *
   * This function does nothing if called when no mocks are active.
   */
  ;

  _proto.$restore = function $restore() {
    var _this2 = this;

    var proto = Object.getPrototypeOf(this);
    Object.keys(this.$meta).forEach(function (alias) {
      if (proto.hasOwnProperty(alias)) {
        // Skip imports which conflict with special methods.
        return;
      }

      var _this2$$meta$alias = _this2.$meta[alias],
          value = _this2$$meta$alias[2];
      _this2[alias] = value;
    });
  };

  return ImportMap;
}();

module.exports = {
  ImportMap: ImportMap,
  MockingError: MockingError
};
